.. py:currentmodule:: rubin_sim.skybrightness_pre

.. _rubin_sim.skybrightness_pre:

===========================
rubin_sim skybrightness_pre
===========================

The rubin_sim.skybrightness_pre module generates and accesses pre-calculated skybrightness values
over the sky in each bandpass during the expected on-sky period for LSST. The values calculated
by the rubin_sim.skybrightness module are packaged into data files which are then read and passed to
the scheduler by rubin_sim.skybrightness_pre.


Python API
==========

* :ref:`rubin_sim.skybrightness_pre api`

* :ref:`search`